Crate pash[−][src]
pash library is a part of pash cli tool.
It is a simple-to-use tool for generating and storing passwords
usage:
If you are using pash for first time, run pash --init in your shell. This will generate necessary files.
if you wish to create new password, run pash create. You can specify category using -c or --category flag (pash create yt -c social)
configuration:
Your passwords and config are stored at $HOME/.config/pash (on linux) or %APPDATA%/pash (on windows).
example config:
lowercase = true # include lowercase characters
uppercase = true
symbols = true
numbers = false # exclude numbers
begin_with_letter = false # random first character
length = 10
category = "different" # default category
WARNING: passwords won’t generate if you leave
length = 0.
Modules
| cli | Clap’s CLI interface interaction |
| files | This module deals with creating files and editing them. |
| generator | Password generator |